@@ -1566,25 +1566,10 @@ int spider_udf_set_direct_sql_param_default(
     }
   }
 
-  if (direct_sql->table_loop_mode == -1)
-    direct_sql->table_loop_mode = 0;
   if (direct_sql->priority == -1)
     direct_sql->priority = 1000000;
-  if (direct_sql->connect_timeout == -1)
-    direct_sql->connect_timeout = 6;
-  if (direct_sql->net_read_timeout == -1)
-    direct_sql->net_read_timeout = 600;
-  if (direct_sql->net_write_timeout == -1)
-    direct_sql->net_write_timeout = 600;
-  if (direct_sql->bulk_insert_rows == -1)
-    direct_sql->bulk_insert_rows = 3000;
   if (direct_sql->connection_channel == -1)
     direct_sql->connection_channel = 0;
-#if MYSQL_VERSION_ID < 50500
-#else
-  if (direct_sql->use_real_table == -1)
-    direct_sql->use_real_table = 0;
-#endif
   if (direct_sql->error_rw_mode == -1)
     direct_sql->error_rw_mode = 0;
   for (roop_count = 0; roop_count < direct_sql->table_count; roop_count++)
